@@ -121,15 +121,17 @@ public:
 		m_value.clear();
 	}
 
+	bool is_status () const
+		{ return (m_status & 0x800) && (m_status & 0x700); }
 	void set_status(unsigned short status)
-		{ m_status = status; }
+		{ m_status = (status & 0x7ff) | 0x800; }
 	unsigned short status() const
-		{ return m_status; }
+		{ return (m_status & 0x7ff); }
 
 	drumkv1_controls::Type type() const
-		{ return drumkv1_controls::Type(m_status & 0xf00); }
+		{ return drumkv1_controls::Type(status() & 0x700); }
 	unsigned short channel() const
-		{ return (m_status & 0x1f); }
+		{ return (status() & 0x1f); }
 
 	bool is_param_msb() const
 		{ return m_param.is_msb(); }
@@ -176,6 +178,9 @@ public:
 	bool is_14bit() const
 		{ return m_param.is_any() && m_value.is_14bit(); }
 
+	void clear_value()
+		{ m_status &= 0x7ff; m_value.clear(); }
+
 private:
 
 	unsigned short m_status;
@@ -327,10 +332,21 @@ public:
 
 		if (event.key.param == RPN_MSB) {
 			xrpn_item& item = get_item(channel);
-			if (item.is_param_msb()
-				|| (item.is_any() && item.type() != drumkv1_controls::RPN))
+			if (item.is_any() && item.type() != drumkv1_controls::RPN)
 				enqueue(item);
-			if (item.type() == drumkv1_controls::None) {
+			if (item.is_status() // RPN NULL [MSB]
+				&& item.type() == drumkv1_controls::RPN && item.is_param_lsb()
+				&& item.param_lsb() == 0x7f && event.value == 0x7f) {
+				item.clear();
+				--m_count;
+				return true;
+			}
+			if (item.type() == drumkv1_controls::NRPN) {
+				item.clear();
+				item.set_status(drumkv1_controls::RPN | channel);
+			}
+			else
+			if (!item.is_status()) {
 				item.set_status(drumkv1_controls::RPN | channel);
 				++m_count;
 			}
@@ -340,10 +356,21 @@ public:
 		else
 		if (event.key.param == RPN_LSB) {
 			xrpn_item& item = get_item(channel);
-			if (item.is_param_lsb()
-				|| (item.is_any() && item.type() != drumkv1_controls::RPN))
+			if (item.is_any() && item.type() != drumkv1_controls::RPN)
 				enqueue(item);
-			if (item.type() == drumkv1_controls::None) {
+			if (item.is_status() // RPN NULL [LSB]
+				&& item.type() == drumkv1_controls::RPN && item.is_param_msb()
+				&& item.param_msb() == 0x7f && event.value == 0x7f) {
+				item.clear();
+				--m_count;
+				return true;
+			}
+			if (item.type() == drumkv1_controls::NRPN) {
+				item.clear();
+				item.set_status(drumkv1_controls::RPN | channel);
+			}
+			else
+			if (!item.is_status()) {
 				item.set_status(drumkv1_controls::RPN | channel);
 				++m_count;
 			}
@@ -353,10 +380,14 @@ public:
 		else
 		if (event.key.param == NRPN_MSB) {
 			xrpn_item& item = get_item(channel);
-			if (item.is_param_msb()
-				|| (item.is_any() && item.type() != drumkv1_controls::NRPN))
+			if (item.is_any() && item.type() != drumkv1_controls::NRPN)
 				enqueue(item);
-			if (item.type() == drumkv1_controls::None) {
+			if (item.type() == drumkv1_controls::RPN) {
+				item.clear();
+				item.set_status(drumkv1_controls::NRPN | channel);
+			}
+			else
+			if (!item.is_status()) {
 				item.set_status(drumkv1_controls::NRPN | channel);
 				++m_count;
 			}
@@ -366,10 +397,14 @@ public:
 		else
 		if (event.key.param == NRPN_LSB) {
 			xrpn_item& item = get_item(channel);
-			if (item.is_param_lsb()
-				|| (item.is_any() && item.type() != drumkv1_controls::NRPN))
+			if (item.is_any() && item.type() != drumkv1_controls::NRPN)
 				enqueue(item);
-			if (item.type() == drumkv1_controls::None) {
+			if (item.type() == drumkv1_controls::RPN) {
+				item.clear();
+				item.set_status(drumkv1_controls::NRPN | channel);
+			}
+			else
+			if (!item.is_status()) {
 				item.set_status(drumkv1_controls::NRPN | channel);
 				++m_count;
 			}
@@ -379,14 +414,13 @@ public:
 		else
 		if (event.key.param == DATA_MSB) {
 			xrpn_item& item = get_item(channel);
-			if (item.type() == drumkv1_controls::None)
-				return false;
-			if (item.is_value_msb()
-				|| (item.type() != drumkv1_controls::RPN
-				 && item.type() != drumkv1_controls::NRPN)) {
+			if (item.type() != drumkv1_controls::RPN &&
+				item.type() != drumkv1_controls::NRPN) {
 				enqueue(item);
 				return false;
 			}
+			if (!item.is_status())
+				item.set_status(item.type() | channel);
 			item.set_value_msb(event.value);
 			if (item.is_14bit())
 				enqueue(item);
@@ -395,29 +429,32 @@ public:
 		else
 		if (event.key.param == DATA_LSB) {
 			xrpn_item& item = get_item(channel);
-			if (item.type() == drumkv1_controls::None)
-				return false;
-			if (item.is_value_lsb()
-				|| (item.type() != drumkv1_controls::RPN
-				 && item.type() != drumkv1_controls::NRPN)) {
+			if (item.type() != drumkv1_controls::RPN &&
+				item.type() != drumkv1_controls::NRPN) {
 				enqueue(item);
 				return false;
 			}
+			if (!item.is_status())
+				item.set_status(item.type() | channel);
 			item.set_value_lsb(event.value);
 			if (item.is_14bit())
 				enqueue(item);
 			return true;
 		}
 		else
-		if (event.key.param > CC14_MSB_MIN &&
-			event.key.param < CC14_MSB_MAX) {
+		if (event.key.param > CC14_MSB_MIN && event.key.param < CC14_MSB_MAX) {
 			xrpn_item& item = get_item(channel);
+			if (item.is_any() && item.type() != drumkv1_controls::CC14) {
+				enqueue(item);
+				item.clear();
+				--m_count;
+			}
+			else
 			if (item.is_param_msb() || item.is_value_msb()
-				|| (item.is_any() && item.type() != drumkv1_controls::CC14)
 				|| (item.type() == drumkv1_controls::CC14
 					&& item.param_lsb() != event.key.param + CC14_LSB_MIN))
 				enqueue(item);
-			if (item.type() == drumkv1_controls::None) {
+			if (!item.is_status()) {
 				item.set_status(drumkv1_controls::CC14 | channel);
 				++m_count;
 			}
@@ -428,15 +465,19 @@ public:
 			return true;
 		}
 		else
-		if (event.key.param > CC14_LSB_MIN &&
-			event.key.param < CC14_LSB_MAX) {
+		if (event.key.param > CC14_LSB_MIN && event.key.param < CC14_LSB_MAX) {
 			xrpn_item& item = get_item(channel);
+			if (item.is_any() && item.type() != drumkv1_controls::CC14) {
+				enqueue(item);
+				item.clear();
+				--m_count;
+			}
+			else
 			if (item.is_param_lsb() || item.is_value_lsb()
-				|| (item.is_any() && item.type() != drumkv1_controls::CC14)
 				|| (item.type() == drumkv1_controls::CC14
 					&& item.param_msb() != event.key.param - CC14_LSB_MIN))
 				enqueue(item);
-			if (item.type() == drumkv1_controls::None) {
+			if (!item.is_status()) {
 				item.set_status(drumkv1_controls::CC14 | channel);
 				++m_count;
 			}
@@ -457,7 +498,7 @@ protected:
 
 	void enqueue ( xrpn_item& item )
 	{
-		if (item.type() == drumkv1_controls::None)
+		if (!item.is_status())
 			return;
 
 		if (item.type() == drumkv1_controls::CC14) {
@@ -471,10 +512,14 @@ protected:
 				if (item.is_value_lsb())
 					m_queue.push(status, item.param_lsb(), item.value_lsb());
 			}
+			item.clear();
+			--m_count;
 		}
 		else
 		if (item.is_ready()) {
 			m_queue.push(item.status(), item.param(), item.value());
+			item.clear_value();
+		//	--m_count;
 		} else {
 			const unsigned short status
 				= drumkv1_controls::CC | item.channel();
@@ -495,10 +540,9 @@ protected:
 				m_queue.push(status, DATA_MSB, item.value_msb());
 			if (item.is_value_lsb())
 				m_queue.push(status, DATA_LSB, item.value_lsb());
+			item.clear();
+			--m_count;
 		}
-
-		item.clear();
-		--m_count;
 	}
 
 private:
@@ -603,13 +647,14 @@ void drumkv1_controls::process_event ( const Event& event )
 
 	// catch-up testing begin...
 	bool bSync = (data.flags & Hook) || !drumkv1_param::paramFloat(index);
-
+	if (!bSync)
+		bSync = data.sync;
 	if (!bSync) {
 		const float v0 = data.val;
 		const float v1 = drumkv1_param::paramScale(index,
 			m_sched_in.instance()->paramValue(index));
 		const float d1 = (v1 - fScale);
-		const float d2 = (data.sync ? (v1 - v0) : d1) * d1;
+		const float d2 = (v1 - v0) * d1;
 		bSync = (d2 < 0.001f);
 		if (bSync) {
 			data.val = fScale;
