@@ -605,9 +605,15 @@ void drumkv1_jack::selectSample ( int key )
 }
 
 
+void drumkv1_jack::updatePreset ( bool /*bDirty*/ )
+{
+	// nothing to do here...
+}
+
+
 void drumkv1_jack::updateSample (void)
 {
-	// nothing to do...
+	// nothing to do here...
 }
 
 
@@ -686,8 +692,12 @@ bool drumkv1_jack_application::parse_args (void)
 		}
 		else
 		if (sArg == "-v" || sArg == "-V" || sArg == "--version") {
-			out << QObject::tr("Qt: %1\n").arg(qVersion());
-			out << QObject::tr(DRUMKV1_TITLE ": %1\n").arg(DRUMKV1_VERSION);
+			out << QObject::tr("Qt: %1\n")
+				.arg(qVersion());
+			out << QObject::tr("%1: %2  (%3)\n")
+				.arg(DRUMKV1_TITLE)
+				.arg(CONFIG_BUILD_VERSION)
+				.arg(CONFIG_BUILD_DATE);
 			return false;
 		}
 	}
