@@ -34,11 +34,28 @@
 #include "lv2/lv2plug.in/ns/ext/atom/util.h"
 
 #include "lv2/lv2plug.in/ns/ext/state/state.h"
-#include "lv2/lv2plug.in/ns/ext/patch/patch.h"
 
 #include "lv2/lv2plug.in/ns/ext/options/options.h"
 #include "lv2/lv2plug.in/ns/ext/buf-size/buf-size.h"
 
+#ifdef CONFIG_LV2_PATCH
+#include "lv2/lv2plug.in/ns/ext/patch/patch.h"
+#endif
+
+#ifndef CONFIG_LV2_ATOM_FORGE_OBJECT
+#define lv2_atom_forge_object(forge, frame, id, otype) \
+		lv2_atom_forge_blank(forge, frame, id, otype)
+#endif
+
+#ifndef CONFIG_LV2_ATOM_FORGE_KEY
+#define lv2_atom_forge_key(forge, key) \
+		lv2_atom_forge_property_head(forge, key, 0)
+#endif
+
+#ifndef LV2_STATE__StateChanged
+#define LV2_STATE__StateChanged LV2_STATE_PREFIX "StateChanged"
+#endif
+
 #include <stdlib.h>
 #include <math.h>
 
@@ -106,14 +123,11 @@ private:
 
 // atom-like message used internally with worker/schedule
 typedef struct {
-
 	LV2_Atom atom;
-
 	union {
 		int key;
 		const char *path;
 	} sample;
-
 } drumkv1_lv2_worker_message;
 
 
@@ -121,12 +135,13 @@ drumkv1_lv2::drumkv1_lv2 (
 	double sample_rate, const LV2_Feature *const *host_features )
 	: drumkv1(2, float(sample_rate))
 {
+	::memset(&m_urids, 0, sizeof(m_urids));
+
 	m_urid_map = NULL;
 	m_atom_in  = NULL;
 	m_atom_out = NULL;
 	m_schedule = NULL;
-
-	m_ndelta = 0;
+	m_ndelta   = 0;
 
 	const LV2_Options_Option *host_options = NULL;
 
@@ -165,6 +180,9 @@ drumkv1_lv2::drumkv1_lv2 (
 				m_urids.bufsz_nominalBlockLength = m_urid_map->map(
 					m_urid_map->handle, LV2_BUF_SIZE__nominalBlockLength);
 			#endif
+				m_urids.state_StateChanged = m_urid_map->map(
+					m_urid_map->handle, LV2_STATE__StateChanged);
+			#ifdef CONFIG_LV2_PATCH
 				m_urids.patch_Get = m_urid_map->map(
  					m_urid_map->handle, LV2_PATCH__Get);
 				m_urids.patch_Set = m_urid_map->map(
@@ -177,6 +195,7 @@ drumkv1_lv2::drumkv1_lv2 (
  					m_urid_map->handle, LV2_PATCH__property);
 				m_urids.patch_value = m_urid_map->map(
  					m_urid_map->handle, LV2_PATCH__value);
+			#endif
 			}
 		}
 		else
@@ -310,6 +329,7 @@ void drumkv1_lv2::run ( uint32_t nframes )
 							drumkv1::setTempo(host_bpm);
 					}
 				}
+			#ifdef CONFIG_LV2_PATCH
 				else 
 				if (object->body.otype == m_urids.patch_Set) {
 					// set property value
@@ -341,6 +361,7 @@ void drumkv1_lv2::run ( uint32_t nframes )
 					// put property values (probably to UI)
 					patch_put(ndelta);
 				}
+			#endif	// CONFIG_LV2_PATCH
 			}
 		}
 		// remember last time for worker response
@@ -511,15 +532,15 @@ void drumkv1_lv2::select_program ( uint32_t bank, uint32_t program )
 #endif	// CONFIG_LV2_PROGRAMS
 
 
-void drumkv1_lv2::selectSample ( int key )
+void drumkv1_lv2::updatePreset ( bool /*bDirty*/ )
 {
-	if (m_schedule) {
+	if (m_schedule /*&& bDirty*/) {
 		drumkv1_lv2_worker_message mesg;
-		mesg.atom.type = m_urids.gen1_select;
-		mesg.atom.size = sizeof(mesg.sample);
-		mesg.sample.key = key;
+		mesg.atom.type = m_urids.state_StateChanged;
+		mesg.atom.size = 0; // nothing else matters.
+		mesg.sample.path = NULL;
 		m_schedule->schedule_work(
-		    m_schedule->handle, sizeof(mesg), &mesg);
+			m_schedule->handle, sizeof(mesg), &mesg);
 	}
 }
 
@@ -537,6 +558,81 @@ void drumkv1_lv2::updateSample (void)
 }
 
 
+void drumkv1_lv2::selectSample ( int key )
+{
+	if (m_schedule) {
+		drumkv1_lv2_worker_message mesg;
+		mesg.atom.type = m_urids.gen1_select;
+		mesg.atom.size = sizeof(mesg.sample);
+		mesg.sample.key = key;
+		m_schedule->schedule_work(
+		    m_schedule->handle, sizeof(mesg), &mesg);
+	}
+}
+
+
+bool drumkv1_lv2::worker_work ( const void *data, uint32_t /*size*/ )
+{
+	const drumkv1_lv2_worker_message *mesg
+		= (const drumkv1_lv2_worker_message *) data;
+
+	if (mesg->atom.type == m_urids.state_StateChanged)
+		return true;
+	else
+	if (mesg->atom.type == m_urids.gen1_update)
+		return true;
+	else
+	if (mesg->atom.type == m_urids.gen1_select) {
+		drumkv1::setCurrentElementEx(mesg->sample.key);
+		return true;
+	}
+	else
+	if (mesg->atom.type == m_urids.gen1_sample) {
+		const int key = drumkv1::currentElement();
+		if (drumkv1::element(key) == NULL) {
+			drumkv1::addElement(key);
+			drumkv1::setCurrentElementEx(key);
+		}
+		drumkv1::setSampleFile(mesg->sample.path);
+		return true;
+	}
+
+	return false;
+}
+
+
+bool drumkv1_lv2::worker_response ( const void *data, uint32_t /*size*/ )
+{
+	const drumkv1_lv2_worker_message *mesg
+		= (const drumkv1_lv2_worker_message *) data;
+	if (mesg->atom.type == m_urids.state_StateChanged)
+		return state_changed();
+
+	// update all properties, and eventually, any observers...
+	drumkv1_sched::sync_notify(this, drumkv1_sched::Sample, 0);
+
+#ifdef CONFIG_LV2_PATCH
+	return patch_put(m_ndelta);
+#else
+	return true;
+#endif
+}
+
+
+bool drumkv1_lv2::state_changed (void)
+{
+	lv2_atom_forge_frame_time(&m_forge, m_ndelta);
+
+	LV2_Atom_Forge_Frame frame;
+	lv2_atom_forge_object(&m_forge, &frame, 0, m_urids.state_StateChanged);
+	lv2_atom_forge_pop(&m_forge, &frame);
+
+	return true;
+}
+
+
+#ifdef CONFIG_LV2_PATCH
+
 bool drumkv1_lv2::patch_put ( uint32_t ndelta )
 {
 	static char s_szNull[1] = {'\0'};
@@ -564,41 +660,7 @@ bool drumkv1_lv2::patch_put ( uint32_t ndelta )
 	return true;
 }
 
-
-bool drumkv1_lv2::worker_work ( const void *data, uint32_t /*size*/ )
-{
-	const drumkv1_lv2_worker_message *mesg
-		= (const drumkv1_lv2_worker_message *) data;
-
-	if (mesg->atom.type == m_urids.gen1_update)
-		return true;
-	else
-	if (mesg->atom.type == m_urids.gen1_select) {
-		drumkv1::setCurrentElementEx(mesg->sample.key);
-		return true;
-	}
-	else
-	if (mesg->atom.type == m_urids.gen1_sample) {
-		const int key = drumkv1::currentElement();
-		if (drumkv1::element(key) == NULL) {
-			drumkv1::addElement(key);
-			drumkv1::setCurrentElementEx(key);
-		}
-		drumkv1::setSampleFile(mesg->sample.path);
-		return true;
-	}
-
-	return false;
-}
-
-
-bool drumkv1_lv2::worker_response ( const void */*data*/, uint32_t /*size*/ )
-{
-	// update all properties, and eventually, any observers...
-	drumkv1_sched::sync_notify(this, drumkv1_sched::Sample, 0);
-
-	return patch_put(m_ndelta);
-}
+#endif	// CONFIG_LV2_PATCH
 
 
 //-------------------------------------------------------------------------
