@@ -1,7 +1,7 @@
 // drumkv1_sample.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2015, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2016, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -69,9 +69,9 @@ private:
 
 // ctor.
 drumkv1_sample::drumkv1_sample ( drumkv1 *pDrumk, float srate )
-	: m_srate(srate), m_filename(0), m_nchannels(0),
+	: m_srate(srate), m_filename(NULL), m_nchannels(0),
 		m_rate0(0.0f), m_freq0(1.0f), m_ratio(0.0f),
-		m_nframes(0), m_pframes(0), m_reverse(false)
+		m_nframes(0), m_pframes(NULL), m_reverse(false)
 {
 	m_reverse_sched = new drumkv1_reverse_sched(pDrumk, this);
 }
@@ -89,7 +89,7 @@ drumkv1_sample::~drumkv1_sample (void)
 // init.
 bool drumkv1_sample::open ( const char *filename, float freq0 )
 {
-	if (!filename)
+	if (filename == NULL)
 		return false;
 
 	close();
@@ -100,7 +100,7 @@ bool drumkv1_sample::open ( const char *filename, float freq0 )
 	::memset(&info, 0, sizeof(info));
 	
 	SNDFILE *file = ::sf_open(m_filename, SFM_READ, &info);
-	if (!file)
+	if (file == NULL)
 		return false;
 
 	m_nchannels = info.channels;
@@ -145,7 +145,7 @@ void drumkv1_sample::close (void)
 		for (uint16_t k = 0; k < m_nchannels; ++k)
 			delete [] m_pframes[k];
 		delete [] m_pframes;
-		m_pframes = 0;
+		m_pframes = NULL;
 	}
 
 	m_nframes   = 0;
@@ -156,7 +156,7 @@ void drumkv1_sample::close (void)
 
 	if (m_filename) {
 		::free(m_filename);
-		m_filename = 0;
+		m_filename = NULL;
 	}
 }
 
