@@ -1,7 +1,7 @@
 // drumkv1_sample.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2015, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2016, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -141,7 +141,7 @@ class drumkv1_generator
 public:
 
 	// ctor.
-	drumkv1_generator(drumkv1_sample *sample = 0) { reset(sample); }
+	drumkv1_generator(drumkv1_sample *sample = NULL) { reset(sample); }
 
 	// sample accessor.
 	drumkv1_sample *sample() const
