@@ -1409,8 +1409,8 @@ void drumkv1widget::helpAbout (void)
 	QString sText = "<p>\n";
 	sText += "<b>" DRUMKV1_TITLE "</b> - " + tr(DRUMKV1_SUBTITLE) + "<br />\n";
 	sText += "<br />\n";
-	sText += tr("Version") + ": <b>" DRUMKV1_VERSION "</b><br />\n";
-	sText += "<small>" + tr("Build") + ": " __DATE__ " " __TIME__ "</small><br />\n";
+	sText += tr("Version") + ": <b>" CONFIG_BUILD_VERSION "</b><br />\n";
+	sText += "<small>" + tr("Build") + ": " CONFIG_BUILD_DATE "</small><br />\n";
 	QStringListIterator iter(list);
 	while (iter.hasNext()) {
 		sText += "<small><font color=\"red\">";
@@ -1442,6 +1442,10 @@ void drumkv1widget::helpAboutQt (void)
 // Dirty flag (overridable virtual) methods.
 void drumkv1widget::updateDirtyPreset ( bool bDirtyPreset )
 {
+	drumkv1_ui *pDrumkUi = ui_instance();
+	if (pDrumkUi)
+		pDrumkUi->updatePreset(bDirtyPreset);
+
 	m_ui.StatusBar->setModified(bDirtyPreset);
 	m_ui.Preset->setDirtyPreset(bDirtyPreset);
 }
