@@ -1,7 +1,7 @@
 // drumkv1widget.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2015, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2016, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -125,9 +125,6 @@ protected slots:
 	// Swap params A/B.
 	void swapParams(bool bOn);
 
-	// Delay BPM change.
-	void bpmSyncChanged();
-
 	// Notification updater.
 	void updateSchedNotify(int stype, int sid);
 
@@ -148,6 +145,9 @@ protected:
 	// Reload all elements.
 	void refreshElements();
 
+	// Update element (as current).
+	void updateElement();
+
 	// Reset swap params A/B group.
 	void resetSwapParams();
 
